---
title: Whoops that page was not found
date: 2022-09-01 1:00:00
description: 404, looks like we can't find the page you are looking for
published: false
output_html: 404.html

---

404, looks like we can't find the page you are looking for.  Try one of these
pages.

<ul>
{% for post in markata.map('post', filter='published') %}
    <li><a href="{{ post.slug }}">{{ post.title }}</a></li>
{% endfor %}
</ul>

